@@ -2,6 +2,7 @@ import json
 import logging
 import os
 import re
+from ast import Str
 from tempfile import NamedTemporaryFile
 from xml.dom import ValidationErr
 
@@ -31,15 +32,17 @@ from sensiml.datamanager import (
 from sensiml.datamanager.captures import CaptureExistsError
 from sensiml.datamanager.knowledgepack import delete_knowledgepack, get_knowledgepack
 from sensiml.datasets import DataSets
+from sensiml.dclproj.upload import upload_project
 
 # from sensiml.base.exceptions import *
 from sensiml.pipeline import Pipeline
 
 config_dir = user_config_dir(__name__.split(".")[0], False)
+SERVER_URL = "https://sensiml.cloud/"
 
 logger = logging.getLogger("SensiML")
 
-__version__ = "2022.3.0"
+__version__ = "2022.3.2"
 
 
 def project_set(func):
@@ -91,7 +94,7 @@ def print_list(func):
 
         if func.__name__ == "list_sandboxes":
             extra = [
-                {"CPU Used (seconds)": item.last_cpu_clock_time}
+                {"CPU Used (seconds)": item.cpu_clock_time}
                 for name, item in result.items()
             ]
             additional_keys = ["CPU Used (seconds)"]
@@ -110,7 +113,7 @@ def print_list(func):
 class Client(object):
     def __init__(
         self,
-        server="https://sensiml.cloud/",
+        server=SERVER_URL,
         path="connect.cfg",
         use_jedi=False,
         insecure=False,
@@ -162,6 +165,9 @@ class Client(object):
         response = self._connection.request("get", url)
         response_data, err = utility.check_server_response(response)
 
+        if response_data.get("SensiML_Python_Library_Windows_Minimum") is None:
+            return True
+
         if version.parse(
             response_data["SensiML_Python_Library_Windows_Minimum"]
         ) > version.parse(__version__):
@@ -185,6 +191,24 @@ class Client(object):
 
         Connection.logout(name)
 
+    def get_url(self, url):
+
+        response = self._connection.request("get", url)
+        print(response.json())
+        return response
+
+    def account_info(self):
+        """Get information about your account Usage"""
+
+        url = "team-info/"
+        return self.get_url(url)
+
+    def account_subscription(self):
+        """Get information about your account Subscription"""
+
+        url = "team-subscription/"
+        return self.get_url(url)
+
     def get_function(self, name):
         """Gets a function method call"""
         return self.functions.function_list[name]
@@ -634,7 +658,9 @@ class Client(object):
 
         return result
 
-    def upload_sensor_dataframe(self, name, dataframe, force=False):
+    def upload_sensor_dataframe(
+        self, name: str, dataframe: DataFrame, force: bool = False
+    ):
         """Upload a pandas DataFrame as a DataFile to the server.
 
         DataFiles include sensor data and metadata and can be used in any any step prior to feature generation
@@ -660,7 +686,9 @@ class Client(object):
 
         return result
 
-    def upload_feature_dataframe(self, name, dataframe, force=False):
+    def upload_feature_dataframe(
+        self, name: str, dataframe: DataFrame, force: bool = False
+    ):
         """Upload a pandas DataFrame as a FeatureFile to the server.
 
         FeatureFiles are a collection of feature vectors and can be used in any step after the feature generation step
@@ -692,7 +720,7 @@ class Client(object):
                 if re.match(r"_token.json$", filename):
                     os.unlink(filename)
 
-    def get_feature_statistics_results(self, query_name):
+    def get_feature_statistics_results(self, query_name: str):
         query = self._project.queries.get_query_by_name(query_name)
 
         for i in range(100):
@@ -705,114 +733,15 @@ class Client(object):
         print("Not able to reach the results in the expected time. ")
         return results
 
-    def upload_project(self, name, dclprojpath, asynchronous=True):
+    def upload_project(self, name: str, dclproj_path: str):
+        """Upload a .dclproj file to the server
+
+        Args:
+            name (str): name of the project to create
+            dclproj_path (str): path to the .dclproj file
+        """
         if name in self.list_projects()["Name"].values:
             print("Project with this name already exists.")
             return
 
-        self.project = name
-        capture_metadata = None
-        basedir = os.path.dirname(dclprojpath)
-        capture_dir = os.path.join(basedir, "data")
-        segment_map = {}
-
-        with open(dclprojpath, "r") as f:
-            dclproj = json.load(f)
-
-        plugin_config = dclproj.get("ProjectCapturePluginConfig", None)
-        if plugin_config is not None:
-            self.project.plugin_config = plugin_config
-            print("Capture Config Found, Updating...")
-            self.project.update()
-
-        for segmenter in dclproj.get("ProjectSegmenters"):
-
-            if segmenter.get("parameters", None):
-                params = json.loads(segmenter.get("parameters"))
-                call = self.functions.create_function_call(params["name"])
-                for k, v in params["inputs"].items():
-                    setattr(call, k, v)
-            else:
-                call = None
-
-            new_segmenter = self.project.add_segmenter(
-                segmenter.get("name"),
-                call,
-                preprocess=segmenter.get("preprocess"),
-                custom=segmenter.get("custom"),
-            )
-
-            segment_map[segmenter["name"]] = new_segmenter["id"]
-            segment_map[segmenter["id"]] = new_segmenter["id"]
-
-        capture_files = os.listdir(capture_dir)
-        for capture in capture_files:
-            print("Uploading Capture data, metadata, and labels for {}".format(capture))
-            try:
-
-                capture_metadata = {}
-                file_metadata = []
-                if os.path.exists(
-                    os.path.join(
-                        basedir, "metadata", os.path.basename(capture)[:-3] + "dcl"
-                    )
-                ):
-                    with open(
-                        os.path.join(
-                            basedir, "metadata", os.path.basename(capture)[:-3] + "dcl"
-                        ),
-                        "r",
-                    ) as f:
-                        capture_metadata = json.load(f)
-                        file_metadata = capture_metadata.pop("FileMetadata")
-
-                capture_obj = self.project.captures.create_capture(
-                    os.path.basename(capture),
-                    os.path.join(capture_dir, capture),
-                    capture_info=capture_metadata,
-                    asynchronous=asynchronous,
-                )
-                for metadata in file_metadata:
-                    print("metadata", metadata["name"], metadata["value"])
-                    metadata_obj = capture_obj.metadataset.new_metadata()
-                    metadata_obj.value = metadata["value"]
-                    metadata_obj.name = metadata["name"]
-                    metadata_obj.insert()
-
-                for segment_dir in os.listdir(os.path.join(basedir, "segments")):
-                    if not os.path.exists(
-                        os.path.join(
-                            basedir,
-                            "segments",
-                            segment_dir,
-                            os.path.basename(capture)[:-3] + "sdcl",
-                        )
-                    ):
-                        continue
-
-                    with open(
-                        os.path.join(
-                            basedir,
-                            "segments",
-                            segment_dir,
-                            os.path.basename(capture)[:-3] + "sdcl",
-                        ),
-                        "r",
-                    ) as f:
-                        segment_labels = json.load(f).pop("DetectedSegments")
-
-                    for segment in segment_labels:
-                        for label in segment["LabelData"]:
-                            print("label", label["name"], label["value"])
-                            label_obj = capture_obj.labelset.new_label()
-                            label_obj.sample_start = label[
-                                "capture_sample_sequence_start"
-                            ]
-                            label_obj.sample_end = label["capture_sample_sequence_end"]
-                            label_obj.value = label["value"]
-                            label_obj.name = label["name"]
-                            label_obj.segmenter = segment_map[label["segmenter"]]
-                            label_obj.insert()
-
-            except CaptureExistsError:
-                print("{} already uploaded to this project.".format(capture))
+        upload_project(self, name, dclproj_path)
