@@ -196,7 +196,7 @@ class Project(object):
                 "Cannot query optimize {} until there are uploaded captures.".format(
                     self._name
                 )
-                + "If data was uploaded, try dsk.project.refresh() followed by dsk.project.query_optimize()."
+                + "If data was uploaded, try client.project.refresh() followed by client.project.query_optimize()."
             )
         elif not self._query_optimized:
             print(
