@@ -87,7 +87,10 @@ class SandboxPipeline:
 
         # if this is the first step
         if len(self._steps) == 0:
-            item.outputs = ["temp.raw"]
+            if item._step_type == "FeatureFileCall":
+                item.outputs = ["temp.raw", "tem.features.raw"]
+            else:
+                item.outputs = ["temp.raw"]
         else:
             item.input_data = self._steps[-1].outputs[0]
             # Count the number of times the name has been used to get unique
@@ -318,7 +321,6 @@ class Sandbox(object):
         self._device_config = DeviceConfig()
         self._created_at = None
         self._last_modified = None
-        self._last_cpu_clock_time = None
         self._active = False
 
     @property
@@ -346,10 +348,6 @@ class Sandbox(object):
     def cache(self):
         return self._cache_enabled
 
-    @property
-    def last_cpu_clock_time(self):
-        return self._last_cpu_clock_time
-
     @property
     def active(self):
         return self._active
@@ -731,7 +729,6 @@ class Sandbox(object):
             self.name = data["name"]
             self.created_at = data.get("created_at", None)
             self.last_modified = data.get("last_modified", None)
-            self._last_cpu_clock_time = data.get("last_cpu_clock_time", None)
             self._active = data.get("active", False)
             if not data.get("cache_enabled", True):
                 self.disable_cache()
@@ -761,7 +758,6 @@ class Sandbox(object):
         self.name = init_dict["name"]
         self.created_at = init_dict.get("created_at", None)
         self.last_modified = init_dict.get("last_modified", None)
-        self._last_cpu_clock_time = init_dict.get("last_cpu_clock_time", None)
         self._active = init_dict.get("active", None)
 
         if not init_dict.get("cache_enabled", True):
