@@ -146,6 +146,7 @@ class DCLProject:
         fields: List[str],
         fk_fields: Optional[Dict] = None,
         query_filter: Optional[str] = None,
+        header=None,
     ):
 
         if tablename not in self._tables:
@@ -182,8 +183,6 @@ class DCLProject:
                 )
             query_join += " ".join(join_fields)
 
-        header = None
-
         if query_filter:
             query_where = (
                 query_filter  # + "AND {}.local_status != 2 ".format(tablename)
@@ -191,7 +190,7 @@ class DCLProject:
         else:
             query_where = ""  # "WHERE {}.local_status != 2 ".format(tablename)
 
-        if fk_fields:
+        if fk_fields and not header:
             header = fields + list(fk_fields.values())
 
         return self._execute_query(query_select + query_join + query_where, header)
@@ -271,7 +270,10 @@ class DCLProject:
         return self._list_table("Segmenter", fields, fk_fields)
 
     def list_capture_segments(
-        self, captures: Optional[List] = None, sessions: Optional[List] = None
+        self,
+        captures: Optional[List] = None,
+        sessions: Optional[List] = None,
+        include_ids: bool = False,
     ) -> DataFrame:
         """Returns a DataFrame of segment information that are in the captures and sessions specified
 
@@ -309,7 +311,6 @@ class DCLProject:
             "uuid",
             "capture_sample_sequence_start",
             "capture_sample_sequence_end",
-            "local_status",
             "created_at",
             "last_modified",
         ]
@@ -319,11 +320,34 @@ class DCLProject:
                 ("Segmenter", "segmenter"),
                 ("Capture", "capture"),
                 ("LabelValue", "label_value"),
+                ("Label", "label"),
             ]
         )
 
+        if include_ids:
+            fields += ["segmenter", "capture", "label", "label_value"]
+            header = [
+                "uuid",
+                "capture_sample_sequence_start",
+                "capture_sample_sequence_end",
+                "created_at",
+                "last_modified",
+                "segmenter_id",
+                "capture_id",
+                "label_id",
+                "label_value_id",
+                "segmenter",
+                "capture",
+                "label_value",
+                "label",
+            ]
+        else:
+            header = None
+
         return (
-            self._list_table("CaptureLabelValue", fields, fk_fields, query_filter)
+            self._list_table(
+                "CaptureLabelValue", fields, fk_fields, query_filter, header=header
+            )
             .reset_index(drop=True)
             .sort_values(by=["capture", "segmenter", "capture_sample_sequence_start"])
         )
@@ -344,7 +368,9 @@ class DCLProject:
 
         return capture_list[capture_list.name == capture].to_dict(orient="records")[0]
 
-    def get_capture_metadata(self, capture: str) -> DataFrame:
+    def get_capture_metadata(
+        self, capture: str, include_ids: bool = False
+    ) -> DataFrame:
         """Gets the metadata for the specified capture
 
         Args:
@@ -360,7 +386,23 @@ class DCLProject:
             [("Capture", "capture"), ("LabelValue", "label_value"), ("Label", "label")]
         )
 
-        df = self._list_table("CaptureMetadataValue", fields, fk_fields=fk_fields)
+        if include_ids:
+            fields += ["capture", "label_value", "label"]
+            header = header = [
+                "uuid",
+                "capture_id",
+                "label_value_id",
+                "label_id",
+                "capture",
+                "label_value",
+                "label",
+            ]
+        else:
+            header = None
+
+        df = self._list_table(
+            "CaptureMetadataValue", fields, fk_fields=fk_fields, header=header
+        )
 
         return df[df["capture"] == capture]
 
