@@ -270,6 +270,18 @@ class SMLRunner(object):
         self._reset_model.argtypes = [ctypes.c_int]
         self._reset_model.restype = ctypes.c_int
 
+        self._kb_get_model_sg_length = clf_lib.kb_get_model_sg_length
+        self._kb_get_model_sg_length.argtypes = [
+            ctypes.c_int,
+        ]
+        self._kb_get_model_sg_length.restype = ctypes.c_int
+
+        self._kb_get_sg_start_index = clf_lib.kb_get_sg_start_index
+        self._kb_get_sg_start_index.argtypes = [
+            ctypes.c_int,
+        ]
+        self._kb_get_sg_start_index.restype = ctypes.c_int
+
         self._sml_get_segment_length = clf_lib.sml_get_segment_length
         self._sml_get_segment_length.argtypes = [
             ctypes.c_int,
@@ -282,6 +294,19 @@ class SMLRunner(object):
             ctypes.POINTER(ctypes.c_int),
         ]
 
+        self._kb_get_segment_data = clf_lib.kb_get_segment_data
+        self._kb_get_segment_data.argtypes = [
+            ctypes.c_int,
+            ctypes.c_int,
+            ctypes.c_int,
+            ctypes.POINTER(ctypes.c_int16),
+        ]
+
+        self._kb_get_model_framelen = clf_lib.kb_get_model_framelen
+        self._kb_get_model_framelen.argtypes = [
+            ctypes.c_int,
+        ]
+
         # self._print_model_map = clf_lib.kb_print_model_map
 
         # self._print_model_result = clf_lib.kb_print_model_result
@@ -423,7 +448,7 @@ class SMLRunner(object):
 
         if self._run_type != run_type:
             print(
-                "This model has already been run with {}. You will need to restart your kernal to run in this mode.".format(
+                "This model has already been run with {}. You will need to restart your kernel to run in this mode.".format(
                     self._run_type
                 )
             )
@@ -434,7 +459,7 @@ class SMLRunner(object):
     def init_model(self):
         """
         This will initialize the parameters of all the models, it should be run once before
-        running anything elese.
+        running anything else.
         """
         if not self._model_initialized:
             self._model_initialized = True
@@ -465,7 +490,7 @@ class SMLRunner(object):
          Returns:
              int: 0 if model does not support dynamic updates
                   -1 if model cannot be updated anymore
-                  1 if model was succesfully updated
+                  1 if model was successfully updated
         """
 
         if not self._initialized():
@@ -497,7 +522,7 @@ class SMLRunner(object):
          Returns:
              int: 0 if model does not support dynamic updates
                   -1 if model cannot be updated anymore
-                  1 if model was succesfully updated
+                  1 if model was successfully updated
         """
 
         if not self._initialized():
@@ -523,7 +548,7 @@ class SMLRunner(object):
         Returns:
            int: 0 if model does not support dynamic scoring
                 -1 if model cannot be scored
-                1 if model was succesfully scored
+                1 if model was successfully scored
         """
         if not self._initialized():
             return
@@ -542,8 +567,8 @@ class SMLRunner(object):
 
     def retrain_model(self, model_index):
         """
-        After a model has been scored, this will retraing the model according
-        to the models supported reinforcment learning approach
+        After a model has been scored, this will restraing the model according
+        to the models supported reinforcement learning approach
 
         Args:
            model_index(int): Index of the model to update
@@ -565,7 +590,7 @@ class SMLRunner(object):
         return ret
 
     def run_model(
-        self, data_sample, model_index, debug_log=False, model_api="run_model"
+        self, data_sample, model_index, debug_log=True, model_api="run_model"
     ):
         """
         This is the main entry point into the pipeline. It takes a single timepoint of data as an array. Adds that sample to the internal ring buffer
@@ -618,11 +643,20 @@ class SMLRunner(object):
 
         return ret
 
-    def recognize_capture(self, data, model_index=0, model_api="run_model"):
+    def recognize_capture(
+        self,
+        data,
+        model_index=0,
+        model_api="run_model",
+        get_feature_vector=False,
+        get_sensor_data=False,
+    ):
+
         M = []
 
         status = [len(data) // 4, len(data) // 2, 3 * len(data) // 4]
         self.flush_model_buffer(model_index=model_index)
+
         for i in range(0, len(data)):
             # pass a single sample
             ret = self.run_model(
@@ -630,17 +664,31 @@ class SMLRunner(object):
             )
 
             if ret >= 0:
-                M.append(
-                    {
-                        "label_value": ret
-                        if self.get_class_map(model_index) is None
-                        else self.get_class_map(model_index).get(ret, ret),
-                        "capture_sample_sequence_start": i
-                        + 1
-                        - self.get_segment_length(model_index=model_index),
-                        "capture_sample_sequence_end": i,
-                    }
-                )
+
+                output_columns = {
+                    "label_value": ret
+                    if self.get_class_map(model_index) is None
+                    else self.get_class_map(model_index).get(ret, ret),
+                    "capture_sample_sequence_start": i
+                    + 1
+                    - self.get_segment_length(model_index=model_index),
+                    "capture_sample_sequence_end": i,
+                }
+
+                if get_feature_vector:
+                    output_columns["feature_vector"] = self.get_feature_vector(
+                        model_index
+                    )
+
+                n_sensors = self.get_model_framelen(model_index)
+
+                if get_sensor_data:
+                    for i in range(n_sensors):
+                        sensor_data = self.get_segment_data(model_index)
+                        output_columns["sensor_data_%d" % i] = sensor_data[i]
+
+                M.append(output_columns)
+
                 # After a classification is received, call sml_reset model to advance the internal buffer.
                 if model_api != "sml_recognition_run":
                     self.reset_model(model_index=model_index)
@@ -833,7 +881,47 @@ class SMLRunner(object):
 
         return pme_pattern
 
-    def get_feature_vector(self, model_index, feature_vector_buffer_size=256):
+    def get_segment_data(self, model_index: int):
+
+        if not self._initialized():
+            return
+
+        model_index_ctype = ctypes.c_int(model_index)
+
+        n_sensors = self._kb_get_model_framelen(model_index_ctype)
+
+        number_samples = self._kb_get_model_sg_length(model_index_ctype)
+        index = self._kb_get_sg_start_index(model_index_ctype)
+
+        number_samples_ctype = ctypes.c_int(number_samples)
+        index_ctype = ctypes.c_int(index)
+
+        buffer_size = number_samples * n_sensors
+        sensor_data_buffer = (ctypes.c_short * buffer_size)()
+
+        self._kb_get_segment_data(
+            model_index_ctype, number_samples_ctype, index_ctype, sensor_data_buffer
+        )
+
+        sensor_data_buffer = list(sensor_data_buffer)
+        sensor_data = []
+        for i in range(0, buffer_size, number_samples):
+            sensor_data.append(sensor_data_buffer[i : i + number_samples])
+
+        return sensor_data
+
+    def get_model_framelen(self, model_index: int):
+
+        if not self._initialized():
+            return
+
+        model_index_ctype = ctypes.c_int(model_index)
+
+        framelen = self._kb_get_model_framelen(model_index_ctype)
+
+        return framelen
+
+    def get_feature_vector(self, model_index, feature_vector_buffer_size=4096):
 
         if not self._initialized():
             return
